package docs

import (
	"os"

	"gitea.libretechconsulting.com/rmcguire/eia-api-go/cmd/eia-client/internal/util"
	"github.com/spf13/cobra"
	"github.com/spf13/cobra/doc"
)

var DocsCmd = &cobra.Command{
	Use:       "docs",
	Aliases:   []string{"documentation"},
	Short:     "Generate documentation for eia-client",
	Args:      cobra.RangeArgs(1, 1),
	ValidArgs: []string{"md", "man", "yaml"},
	Run:       runDocsCmd,
}

func runDocsCmd(cmd *cobra.Command, args []string) {
	outDir, err := cmd.Flags().GetString(util.FLAG_OUTPUT_DIR)
	if err != nil {
		util.Logger(cmd).Fatal().Err(err).Send()
	}

	prepareDocsDir(cmd, outDir)

	switch args[0] {
	case "md":
		err = doc.GenMarkdownTree(cmd.Root(), outDir)
	case "man":
		err = doc.GenManTree(cmd.Root(), &doc.GenManHeader{
			Title:   "EIA Client",
			Section: "1",
		}, outDir)
	case "yaml":
		err = doc.GenYamlTree(cmd.Root(), outDir)
	default:
		util.Logger(cmd).Fatal().Str("docType", args[0]).Msg("invalid doc type given")
	}

	util.Logger(cmd).Info().Err(err).Msg("doc generation complete")
}

func prepareDocsDir(cmd *cobra.Command, outDir string) {
	_, err := os.Stat(outDir)
	if err != nil {
		err = os.Mkdir(outDir, 0o755)
		if err != nil {
			util.Logger(cmd).Fatal().Err(err).Str("outdir", outDir).
				Msg("unable to prepare output directory")
		}
	}
}

func init() {
	DocsCmd.PersistentFlags().StringP(util.FLAG_OUTPUT_DIR, "o", "./docs", "specify output directory for documentation")
}
